@@ -1,4 +1,4 @@
-## Copyright (C) 2023-2024 Andreas Bertsatos <abertsatos@biol.uoa.gr>
+## Copyright (C) 2023-2025 Andreas Bertsatos <abertsatos@biol.uoa.gr>
 ##
 ## This file is part of the statistics package for GNU Octave.
 ##
@@ -130,7 +130,7 @@ function function_texi2html (fcnname, pkgfcns, info)
 
     ## Build side bar function list
     fcn_list = "";
-    cat_name = unique (pkgfcns(:,2));
+    cat_name = unique (pkgfcns(:,2), "stable");
     for i = 1:numel (cat_name)
       ## Expand current category
       if (strcmpi (cat_name{i}, catname))
